@@ -148,8 +148,8 @@ public:
 	proxyButton[2].load("/opt/proxyswitcher/auto.png");
 	
 	//gconf key for last used network
- 	GCONF_KEY_DIR_CON = "/system/osso/connectivity/IAP/";
-	GCONF_KEY_LAST_USED = GCONF_KEY_DIR_CON + "last_used_network";
+ 	GCONF_KEY_DIR_CON = "/system/osso/connectivity/IAP";
+	GCONF_KEY_LAST_USED = GCONF_KEY_DIR_CON + "/last_used_network";
 	lastUsed = new GConfItem(GCONF_KEY_LAST_USED,this);
 	lastUsedNetworkName = lastUsed->value();
 	
